@@ -3,7 +3,7 @@ package App::FfmpegUtils;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-09-05'; # DATE
 our $DIST = 'App-FfmpegUtils'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict;
@@ -108,6 +108,16 @@ _
             schema => ['str*', in=>[qw/ultrafast superfast veryfast faster fast medium slow slower veryslow/]],
             default => 'veryslow',
         },
+        frame_rate => {
+            summary => 'Set frame rate, in fps',
+            schema => 'ufloat*',
+            cmdline_aliases => {r=>{}},
+        },
+        audio_sample_rate => {
+            summary => 'Set audio sample rate, in Hz',
+            schema => 'uint*',
+            cmdline_aliases => {sample_rate=>{}},
+        },
     },
     features => {
         dry_run => 1,
@@ -204,11 +214,16 @@ sub reencode_video_with_libx264 {
         my $ext = $downsized ? ".$downsize_to-crf$crf.mp4" : ".crf$crf.mp4";
         $output_file =~ s/(\.\w{3,4})?\z/($1 eq ".mp4" ? "" : $1) . $ext/e;
 
+        my $audio_is_copy = 1;
+        $audio_is_copy = 0 if defined $args{audio_sample_rate};
+
         push @ffmpeg_args, (
             "-c:v", "libx264",
             "-crf", $crf,
             "-preset", ($args{preset} // 'veryslow'),
-            "-c:a", "copy",
+            (defined $args{frame_rate} ? ("-r", $args{frame_rate}) : ()),
+            "-c:a", ($audio_is_copy ? "copy" : "aac"),
+            (defined $args{audio_sample_rate} ? ("-ar", $args{audio_sample_rate}) : ()),
             $output_file,
         );
 
@@ -245,7 +260,7 @@ App::FfmpegUtils - Utilities related to ffmpeg
 
 =head1 VERSION
 
-This document describes version 0.004 of App::FfmpegUtils (from Perl distribution App-FfmpegUtils), released on 2020-09-05.
+This document describes version 0.005 of App::FfmpegUtils (from Perl distribution App-FfmpegUtils), released on 2020-09-05.
 
 =head1 FUNCTIONS
 
@@ -301,6 +316,10 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
+=item * B<audio_sample_rate> => I<uint>
+
+Set audio sample rate, in Hz.
+
 =item * B<crf> => I<int>
 
 =item * B<downsize_to> => I<str> (default: "1080p")
@@ -315,6 +334,10 @@ C<--dont-downsize> on the CLI.
 
 =item * B<files>* => I<array[filename]>
 
+=item * B<frame_rate> => I<ufloat>
+
+Set frame rate, in fps.
+
 =item * B<preset> => I<str> (default: "veryslow")
 
 
